@@ -3,12 +3,12 @@ directory.py stores methodology to install various files and
 packages to different locations.
 
 """
+import logging
 import os
 import shutil
 import stat
 
-rc_template = \
-"""
+rc_template = """
 export PATH=%s:$PATH
 """
 
@@ -26,9 +26,11 @@ class Directory(object):
                        # preserved, and will not be modifiable
     rc_file = None  # file handler for rc file
 
-    def __init__(self, namespace, rewrite_rc=True, sprinter_root=os.path.join("~", ".sprinter")):
+    def __init__(self, namespace, rewrite_rc=True, sprinter_root=os.path.join("~", ".sprinter"),
+                 logger=logging.getLogger('sprinter')):
         """ takes in a namespace directory to initialize, defaults to .sprinter otherwise."""
         self.root_dir = os.path.expanduser(os.path.join(sprinter_root, namespace))
+        self.logger = logger
         self.new = not os.path.exists(self.root_dir)
         self.manifest_path = os.path.join(self.root_dir, "manifest.cfg")
         self.rewrite_rc = rewrite_rc
@@ -42,7 +44,7 @@ class Directory(object):
         if not os.path.exists(self.root_dir):
             os.makedirs(self.root_dir)
         assert os.path.isdir(self.root_dir), "%s is not a directory! Please move or remove it." % self.root_dir
-        for d in ["bin", "lib"]:
+        for d in ["bin", "lib", "include"]:
             target_path = os.path.join(self.root_dir, d)
             if not os.path.exists(target_path):
                 os.makedirs(target_path)
@@ -57,19 +59,27 @@ class Directory(object):
         shutil.rmtree(self.root_dir)
 
     def symlink_to_bin(self, name, path):
-        """
-        Symlink an object at path to name in the bin folder. remove it if it already exists.
-        """
+        """ Symlink an object at path to name in the bin folder. """
         self.__symlink_dir("bin", name, path)
         os.chmod(os.path.join(self.root_dir, "bin", name), stat.S_IXUSR)
         os.chmod(os.path.join(self.root_dir, "bin", name), stat.S_IXUSR | stat.S_IRUSR)
 
+    def remove_from_bin(self, name):
+        """ Remove an object from the bin folder. """
+        target_path = os.path.join(self.root_dir, "bin", name)
+        if os.path.isdir(target_path):
+            shutil.rmtree(target_path)
+        else:
+            os.unlink(target_path)
+
     def symlink_to_lib(self, name, path):
-        """
-        Symlink an object at path to name in the lib folder. remove it if it already exists.
-        """
+        """ Symlink an object at path to name in the lib folder. """
         self.__symlink_dir("lib", name, path)
 
+    def symlink_to_include(self, name, path):
+        """ Symlink an object at path to name in the lib folder. """
+        self.__symlink_dir("include", name, path)
+
     def bin_path(self):
         """ return the bin directory path """
         return os.path.join(self.root_dir, "bin")
@@ -78,6 +88,10 @@ class Directory(object):
         """ return the lib directory path """
         return os.path.join(self.root_dir, "lib")
 
+    def include_path(self):
+        """ return the include directory path """
+        return os.path.join(self.root_dir, "include")
+
     def install_directory(self, feature_name):
         """
         return a path to the install directory that the feature should install to.
@@ -108,7 +122,9 @@ class Directory(object):
         """
         target_path = os.path.join(self.root_dir, dir_name, name)
         if os.path.exists(target_path):
-            assert not os.path.isdir(target_path), \
-                "%s is not a symlink! please remove it manually." % target_path
-            os.remove(target_path)
+            if os.path.islink(target_path):
+                os.remove(target_path)
+            else:
+                self.logger.warn("%s is not a symlink! please remove it manually." % target_path)
+                return
         os.symlink(path, target_path)
